About
=====

ASN.1 tools.

Project homepage: https://github.com/eerimoq/asn1tools

Installation
============

.. code-block:: python

    pip install asn1tools

Example usage
=============

Scripting
---------

.. code-block:: python

   >>> import asn1tools

See the test suite for additional examples: https://github.com/eerimoq/asn1tools/blob/master/tests/test_asn1tools.py
